#
# spec file for package nautilus-dropbox
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global nautilus_extdir %( pkg-config libnautilus-extension-4 --variable extensiondir )
Name:           nautilus-dropbox
Version:        2020.03.04
Release:        5.3
Summary:        Dropbox client integrated into Nautilus
License:        GPL-3.0-or-later AND CC-BY-ND-3.0
Group:          Productivity/File utilities
URL:            https://www.dropbox.com
Source:         https://www.dropbox.com/download?dl=packages/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE 98.patch dimstar@opensuse.org -- Hack together something to accept GNOME 40 version schemes
Patch0:         https://patch-diff.githubusercontent.com/raw/dropbox/nautilus-dropbox/pull/98.patch
# PATCH-FIX-UPSTREAM 105.patch -- Port to libnautilus-extension-4
Patch1:         https://patch-diff.githubusercontent.com/raw/dropbox/nautilus-dropbox/pull/105.patch
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  gobject-introspection
BuildRequires:  python3-docutils
BuildRequires:  python3-gobject
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libnautilus-extension-4) >= 43.rc

%description
Dropbox is a free service that lets you bring your photos, docs, and videos anywhere
and share them easily. Never email yourself a file again!

%package -n dropbox-cli
Summary:        Dropbox command line interface
Group:          Productivity/File utilities
Requires:       python3-gpg
Requires:       python3-gobject-Gdk
Provides:       dropbox = %{version}
Obsoletes:      dropbox <= 2015.10.28

%description -n dropbox-cli
Dropbox is a free service that lets you bring your photos, docs, and videos anywhere
and share them easily. Never email yourself a file again!

This package provides a basic dropbox command line interface for desktop and downloads a proprietary dropbox client.

%package -n nautilus-extension-dropbox
Summary:        Dropbox client integrated into Nautilus
Group:          Productivity/File utilities
Requires:       dropbox >= %{version}
Supplements:    (nautilus and dropbox-cli)

%description -n nautilus-extension-dropbox
Dropbox is a free service that lets you bring your photos, docs, and videos anywhere
and share them easily. Never email yourself a file again!

This package integrates dropbox seamless into nautilus.

%prep
%autosetup -p1

%build
# Needed for patch0
autoreconf -fiv
%configure \
	--disable-static \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

sed -i '1s|env python|python|' %{buildroot}%{_bindir}/dropbox

%files -n dropbox-cli
%license COPYING
%doc ChangeLog
%{_bindir}/dropbox
%{_datadir}/applications/dropbox.desktop
%{_datadir}/icons/hicolor/*/apps/dropbox.png
%{_mandir}/man1/dropbox.1%{?ext_man}
%{_datadir}/%{name}/

%files -n nautilus-extension-dropbox
%license COPYING
%doc ChangeLog
%{nautilus_extdir}/libnautilus-dropbox.so

%changelog
* Tue Nov 22 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Require python3-gpg instead of python3-gpgme: gpgme is deprecated
  and in the code is already the fallback, which is only used when
  python3-gpg cannot be found.
- Refresh 105.patch based on git (re-download).
* Thu Sep 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 105.patch: Port to libnautilus-extension-4.
- Following the above, add pkgconfig(gtk4) and
  pkgconfig(libnautilus-extension-4) BuildRequires and drop
  pkgconfig(libnautilus-extension) and nautilus-dropbox-gtk4.patch
  and change nautilus_extdir global to check for
  libnautilus-extension-4 and not libnautilus-extension.
* Wed Jan 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add nautilus-dropbox-gtk4.patch: Fix build against Nautils/GTK4.
* Thu Feb 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 98.patch: workaround build script not coping with the new
  GNOME versioning scheme. In case of x.alpha or x.beta version, we
  declare them as x.0.
- Add libtool BuildRequires and call to autoreconf, as above patch
  touches the build system.
* Tue Jan 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2020.03.04:
  + Coerce XDG_CURRENT_DESKTOP to "Unity". This works around the
    dropbox binary that will only activate the indicator icon and
    menu on Ubuntu Unity < 16.10. This patch coerces
    XDG_CURRENT_DESKTOP to report as "Unity" for the
    budgie-desktop.
- Modernize spec.
* Thu Nov 21 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 2019.02.14
  * Add "version" command, which prints out the version of the
    Dropbox daemon and the Dropbox command-line interface.
  * Update gpg warning to tell users to install the Python 3 GPG
    libraries instead of the Python 2 libraries.
  * Fix bug where the dropbox nautilus repo wasn't being added to
    the apt sources correctly on Ubuntu 18.04 and up.
  * Move build dependencies to Python 3.
  * Move to Python 3 and GTK3
  * Fix bug where the Dropbox tray icon wouldn't display on Ubuntu
    Unity and Ubuntu Gnome.
  * Reverts the fix to issue #15, where the tray wouldn't display on
    XFCE. If you're using XFCE, try the workarounds in this ticket:
    https://bugs.launchpad.net/ubuntu/+source/nautilus-dropbox/+bug/1546176
  * Add support for Fedora 23 - 29, Debian stretch and buster
  * Drop support for Fedora releases older than 21, Ubuntu releases
    older than trusty, and Debian releases older than jessie
  * Display link url on `status`
  * Fix canonicalize_path
  * Make `exclude` work with unicode paths
  * Fix bug that caused the Dropbox tray icon to not show up in XFCE & LXDE
  * Add "update" command, which updates the Dropbox client
  * Unlink files that are going to be replaced by the unpack
  * Validate that Dropbox runs after downloading it
  * Use python-gpg instead of python-gpgme if it's installed, since
    python-gpgme is not available in Ubuntu 18.04.
  * Update icons included in package to the redesigned icons
- Drop nautilus-dropbox-fix-crash.patch and nautilus-dropbox-reproducible.patch
  Both fixed upstream.
- Remove BR on desktop-file-utils, python-docutils and python-gtk
- Move to python3, add BR and Requires on python3-gobject and python3-gpgme
* Sun Mar 11 2018 bwiedemann@suse.com
- Add nautilus-dropbox-reproducible.patch to make man pages build
  reproducibly (boo#1047218)
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Nov 24 2017 dimstar@opensuse.org
- Drop README from doc list: it does not contain useful information
  to the user (boo#1069626).
* Fri Nov 24 2017 giecrilj@stegny.2a.pl
- Conditionalize desktop update macros in post/postun for
  suse_version < 1330 only. Later versions use file triggers to
  achieve the same goal.
- Rename dropbox to dropbox-cli: this name 'dropbox' can confuse
  users in believing that this package would provide the actual
  client.
* Sun Nov  8 2015 idonmez@suse.com
- Update to version 2015.20.18:
  + Support for sharelink, proxy, and throttle CLI commands.
* Sat Feb 14 2015 malcolmlewis@opensuse.org
- Update to version 2.10.0:
  + No changelog provided.
* Wed Jan 28 2015 idonmez@suse.com
- Depend on python-gpgme (bnc#909803).
* Thu Oct 16 2014 dimstar@opensuse.org
- Add nautilus-dropbox-fix-crash.patch: fix crash on startup of
  dropbox (boo#900515).
* Sat Aug 23 2014 dimstar@opensuse.org
- Update to version 1.6.2:
  + Minor bugfixing.
* Sun Mar  2 2014 p.drouand@gmail.com
- Update to version 1.6.1:
  + No changelog available.
* Fri Mar 15 2013 dimstar@opensuse.org
- Update to version 1.6.0:
  + No changelog provided.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Mon Sep  3 2012 cfarrell@suse.com
- license update: GPL-3.0+ and CC-BY-ND-3.0
  icons/data licensed under CC-BY-ND-3.0
* Thu Aug 30 2012 dimstar@opensuse.org
- Initial package, version 1.4.0.
